#########################################################################################
# Equations à résoudre : y" + sin(y) = 0 et y" + y' + sin(y) = 0
# Formulation de Cauchy / Utilsation de solve_ivp
#########################################################################################

from scipy.integrate import solve_ivp
from pylab import *

# y" + sin(y) = 0  (respectivement y" + y' + sin(y) = 0)
# y" = - sin(y)    (respectivement y" = - sin(y) - y')
# On remplace cette équation d'ordre 2 par un système de deux équations d'ordre 1 :
# Y = [y,y']
# Y'= system(t,Y) où il convient de définir la fonction system telle qu'attendue par solve_ivp (formulation de Cauchy).

# Ecriture du système d'équations sans puis avec frottement :
def system1(t,Y): # modèle sans frottement
    # Y est un vecteur qui contient Y[0]=y et sa dérivée Y[1]=y'
    # La fonction doit renvoyer le vecteur Y' qui sera interprété comme :
    # Y'[0]=Y[1]=y' et Y'[1]=y"=-sin(y)
    dy1_dt = Y[1]
    dy2_dt = -sin(Y[0])
    return [dy1_dt,dy2_dt]
def system2(t,Y): # modèle avec frottement visqueux
    dy1_dt = Y[1]
    dy2_dt = -sin(Y[0])-Y[1]  # seule cette ligne change
    return [dy1_dt,dy2_dt]

# Paramètres de calcul
t0 = 0    # instant initial (secondes)
tf = 10   # instant final (secondes)
p = 0.1   # pas maxi de calcul (secondes)
# NB : dans la méthode d'intégration de solve_ivp, le pas est variable. On fixera ici seulement sa valeur maximale.

# conditions initiales (valeur initiale du vecteur Y)
C0 = 1    # valeur initiale de y
C1 = 0    # valeur initiale de y'

# Résolution du modèle sans frottement
sol1 = solve_ivp(system1,[t0,tf],[C0,C1],max_step=p)
# Génère sol.t, sol1.y[0] et sol1.y[1] qui sont respectivement les listes des instants et des valeurs correspondantes de y et de y'.

# Résolution du modèle avec frottement
sol2 = solve_ivp(system2,[t0,tf],[C0,C1],max_step=p)

# Tracé de y(t) qui seul nous intéresse ici, c'est-à-dire sol1.y[0] sans frottement et sol2.y[0] avec frottement
plot(sol1.t,sol1.y[0], color='blue', label='sans frottement')
plot(sol2.t,sol2.y[0], color='red', label='avec frottement')
grid()
legend()
show()

